==> zio-aws-codeartifact_2.12-5.17.269.1-sources.jar: zio/aws/codeartifact/model/PutPackageOriginConfigurationRequest.scala <==
package zio.aws.codeartifact.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.codeartifact.model.primitives.{
  PackageName,
  AccountId,
  DomainName,
  RepositoryName,
  PackageNamespace
}
import scala.jdk.CollectionConverters._
final case class PutPackageOriginConfigurationRequest(
    domain: DomainName,
    domainOwner: Optional[AccountId] = Optional.Absent,
    repository: RepositoryName,
    format: zio.aws.codeartifact.model.PackageFormat,
    namespace: Optional[PackageNamespace] = Optional.Absent,
    packageValue: PackageName,
    restrictions: zio.aws.codeartifact.model.PackageOriginRestrictions
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codeartifact.model.PutPackageOriginConfigurationRequest = {
    import PutPackageOriginConfigurationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codeartifact.model.PutPackageOriginConfigurationRequest
      .builder()
      .domain(DomainName.unwrap(domain): java.lang.String)
      .optionallyWith(
        domainOwner.map(value => AccountId.unwrap(value): java.lang.String)
      )(_.domainOwner)
      .repository(RepositoryName.unwrap(repository): java.lang.String)
      .format(format.unwrap)
      .optionallyWith(
        namespace.map(value => PackageNamespace.unwrap(value): java.lang.String)
      )(_.namespace)
      .packageValue(PackageName.unwrap(packageValue): java.lang.String)
      .restrictions(restrictions.buildAwsValue())
      .build()
  }
  def asReadOnly
      : zio.aws.codeartifact.model.PutPackageOriginConfigurationRequest.ReadOnly =
    zio.aws.codeartifact.model.PutPackageOriginConfigurationRequest
      .wrap(buildAwsValue())
}
object PutPackageOriginConfigurationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codeartifact.model.PutPackageOriginConfigurationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.codeartifact.model.PutPackageOriginConfigurationRequest =
      zio.aws.codeartifact.model.PutPackageOriginConfigurationRequest(
        domain,
        domainOwner.map(value => value),
        repository,
        format,
        namespace.map(value => value),
        packageValue,
        restrictions.asEditable
      )
    def domain: DomainName
    def domainOwner: Optional[AccountId]
    def repository: RepositoryName
    def format: zio.aws.codeartifact.model.PackageFormat
    def namespace: Optional[PackageNamespace]
    def packageValue: PackageName
    def restrictions
        : zio.aws.codeartifact.model.PackageOriginRestrictions.ReadOnly
    def getDomain: ZIO[Any, Nothing, DomainName] = ZIO.succeed(domain)
    def getDomainOwner: ZIO[Any, AwsError, AccountId] =
      AwsError.unwrapOptionField("domainOwner", domainOwner)
    def getRepository: ZIO[Any, Nothing, RepositoryName] =
      ZIO.succeed(repository)
    def getFormat: ZIO[Any, Nothing, zio.aws.codeartifact.model.PackageFormat] =
      ZIO.succeed(format)
    def getNamespace: ZIO[Any, AwsError, PackageNamespace] =
      AwsError.unwrapOptionField("namespace", namespace)
    def getPackageValue: ZIO[Any, Nothing, PackageName] =
      ZIO.succeed(packageValue)
    def getRestrictions: ZIO[
      Any,
      Nothing,
      zio.aws.codeartifact.model.PackageOriginRestrictions.ReadOnly
    ] = ZIO.succeed(restrictions)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codeartifact.model.PutPackageOriginConfigurationRequest
  ) extends zio.aws.codeartifact.model.PutPackageOriginConfigurationRequest.ReadOnly {
    override val domain: DomainName =
      zio.aws.codeartifact.model.primitives.DomainName(impl.domain())
    override val domainOwner: Optional[AccountId] = zio.aws.core.internal
      .optionalFromNullable(impl.domainOwner())
      .map(value => zio.aws.codeartifact.model.primitives.AccountId(value))
    override val repository: RepositoryName =
      zio.aws.codeartifact.model.primitives.RepositoryName(impl.repository())
    override val format: zio.aws.codeartifact.model.PackageFormat =
      zio.aws.codeartifact.model.PackageFormat.wrap(impl.format())
    override val namespace: Optional[PackageNamespace] = zio.aws.core.internal
      .optionalFromNullable(impl.namespace())
      .map(value =>
        zio.aws.codeartifact.model.primitives.PackageNamespace(value)
      )
    override val packageValue: PackageName =
      zio.aws.codeartifact.model.primitives.PackageName(impl.packageValue())
    override val restrictions
        : zio.aws.codeartifact.model.PackageOriginRestrictions.ReadOnly =
      zio.aws.codeartifact.model.PackageOriginRestrictions
        .wrap(impl.restrictions())
  }
  def wrap(
      impl: software.amazon.awssdk.services.codeartifact.model.PutPackageOriginConfigurationRequest
  ): zio.aws.codeartifact.model.PutPackageOriginConfigurationRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-codeartifact_3-5.19.33.1-sources.jar: zio/aws/codeartifact/model/PutPackageOriginConfigurationRequest.scala <==
package zio.aws.codeartifact.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.codeartifact.model.primitives.{
  PackageName,
  AccountId,
  DomainName,
  RepositoryName,
  PackageNamespace
}
import scala.jdk.CollectionConverters.*
final case class PutPackageOriginConfigurationRequest(
    domain: DomainName,
    domainOwner: Optional[AccountId] = Optional.Absent,
    repository: RepositoryName,
    format: zio.aws.codeartifact.model.PackageFormat,
    namespace: Optional[PackageNamespace] = Optional.Absent,
    packageValue: PackageName,
    restrictions: zio.aws.codeartifact.model.PackageOriginRestrictions
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codeartifact.model.PutPackageOriginConfigurationRequest = {
    import PutPackageOriginConfigurationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codeartifact.model.PutPackageOriginConfigurationRequest
      .builder()
      .domain(DomainName.unwrap(domain): java.lang.String)
      .optionallyWith(
        domainOwner.map(value => AccountId.unwrap(value): java.lang.String)
      )(_.domainOwner)
      .repository(RepositoryName.unwrap(repository): java.lang.String)
      .format(format.unwrap)
      .optionallyWith(
        namespace.map(value => PackageNamespace.unwrap(value): java.lang.String)
      )(_.namespace)
      .packageValue(PackageName.unwrap(packageValue): java.lang.String)
      .restrictions(restrictions.buildAwsValue())
      .build()
  }
  def asReadOnly
      : zio.aws.codeartifact.model.PutPackageOriginConfigurationRequest.ReadOnly =
    zio.aws.codeartifact.model.PutPackageOriginConfigurationRequest
      .wrap(buildAwsValue())
}
object PutPackageOriginConfigurationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codeartifact.model.PutPackageOriginConfigurationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.codeartifact.model.PutPackageOriginConfigurationRequest =
      zio.aws.codeartifact.model.PutPackageOriginConfigurationRequest(
        domain,
        domainOwner.map(value => value),
        repository,
        format,
        namespace.map(value => value),
        packageValue,
        restrictions.asEditable
      )
    def domain: DomainName
    def domainOwner: Optional[AccountId]
    def repository: RepositoryName
    def format: zio.aws.codeartifact.model.PackageFormat
    def namespace: Optional[PackageNamespace]
    def packageValue: PackageName
    def restrictions
        : zio.aws.codeartifact.model.PackageOriginRestrictions.ReadOnly
    def getDomain: ZIO[Any, Nothing, DomainName] = ZIO.succeed(domain)
    def getDomainOwner: ZIO[Any, AwsError, AccountId] =
      AwsError.unwrapOptionField("domainOwner", domainOwner)
    def getRepository: ZIO[Any, Nothing, RepositoryName] =
      ZIO.succeed(repository)
    def getFormat: ZIO[Any, Nothing, zio.aws.codeartifact.model.PackageFormat] =
      ZIO.succeed(format)
    def getNamespace: ZIO[Any, AwsError, PackageNamespace] =
      AwsError.unwrapOptionField("namespace", namespace)
    def getPackageValue: ZIO[Any, Nothing, PackageName] =
      ZIO.succeed(packageValue)
    def getRestrictions: ZIO[
      Any,
      Nothing,
      zio.aws.codeartifact.model.PackageOriginRestrictions.ReadOnly
    ] = ZIO.succeed(restrictions)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codeartifact.model.PutPackageOriginConfigurationRequest
  ) extends zio.aws.codeartifact.model.PutPackageOriginConfigurationRequest.ReadOnly {
    override val domain: DomainName =
      zio.aws.codeartifact.model.primitives.DomainName(impl.domain())
    override val domainOwner: Optional[AccountId] = zio.aws.core.internal
      .optionalFromNullable(impl.domainOwner())
      .map(value => zio.aws.codeartifact.model.primitives.AccountId(value))
    override val repository: RepositoryName =
      zio.aws.codeartifact.model.primitives.RepositoryName(impl.repository())
    override val format: zio.aws.codeartifact.model.PackageFormat =
      zio.aws.codeartifact.model.PackageFormat.wrap(impl.format())
    override val namespace: Optional[PackageNamespace] = zio.aws.core.internal
      .optionalFromNullable(impl.namespace())
      .map(value =>
        zio.aws.codeartifact.model.primitives.PackageNamespace(value)
      )
    override val packageValue: PackageName =
      zio.aws.codeartifact.model.primitives.PackageName(impl.packageValue())
    override val restrictions
        : zio.aws.codeartifact.model.PackageOriginRestrictions.ReadOnly =
      zio.aws.codeartifact.model.PackageOriginRestrictions
        .wrap(impl.restrictions())
  }
  def wrap(
      impl: software.amazon.awssdk.services.codeartifact.model.PutPackageOriginConfigurationRequest
  ): zio.aws.codeartifact.model.PutPackageOriginConfigurationRequest.ReadOnly =
    new Wrapper(impl)
}
